@@ -11,5 +11,5 @@ class InquiryRequestAdditionalInfo:
         return {
             "channel": self.channel,
             "trxId": self.trx_id,
-            "virtualAccountConfig": self.virtual_acc_config
+            "virtualAccountConfig": self.virtual_acc_config.json()
         }
\ No newline at end of file
