@@ -13,4 +13,14 @@ class TokenB2BResponse :
         self.token_type = tokenType
         self.expires_in = expiresIn
         self.additional_info = additionalInfo
-        self.generated_timestamp = ''
\ No newline at end of file
+        self.generated_timestamp = ''
+    
+    def json(self) -> dict:
+        return {
+            "responseCode": self.response_code,
+            "responseMessage": self.response_message,
+            "accessToken": self.access_token,
+            "tokenType": self.token_type,
+            "expiresIn": self.expires_in,
+            "additionalInfo": self.additional_info
+        }
\ No newline at end of file
