@@ -1,6 +1,6 @@
 class TotalAmount:
 
-    def __init__(self, value: str, currency: str) -> None:
+    def __init__(self, value: str, currency: str = "IDR") -> None:
         self.value = value
         self.currency = currency
     
